@@ -63,7 +63,7 @@ PartitionTable::PartitionTable(const PartitionTable& other)
     for (Partitions::const_iterator it = other.m_Children.constBegin();
          it != other.m_Children.constEnd(); ++it)
     {
-        m_Children.append(new Partition(**it));
+        m_Children.append(new Partition(**it, this));
     }
 }
 
@@ -317,6 +317,10 @@ Partition* createUnallocated(const Device& device, PartitionNode& parent, qint64
     if (!parent.isRoot())
         r |= PartitionRole::Logical;
 
+    // Mark unallocated space in LVM VG as LVM LV so that pasting can be easily disabled (it does not work yet)
+    if (device.type() == Device::LVM_Device)
+        r |= PartitionRole::Lvm_Lv;
+
     if (!PartitionTable::getUnallocatedRange(device, parent, start, end))
         return nullptr;
 
@@ -368,21 +372,22 @@ void PartitionTable::removeUnallocated()
     @param p the parent PartitionNode (may be this or an extended Partition)
     @param start the first sector to begin looking for free space
 */
-void PartitionTable::insertUnallocated(const Device& d, PartitionNode* p, qint64 start) const
+void PartitionTable::insertUnallocated(const Device& d, PartitionNode* p, qint64 start)
 {
     Q_ASSERT(p);
 
     qint64 lastEnd = start;
 
     if (d.type() == Device::LVM_Device && !p->children().isEmpty()) {
-        // rearranging all the partitions sector to keep all the unallocated space at the end
+        // rearranging the sectors of all partitions to keep unallocated space at the end
         lastEnd = 0;
+        qSort(children().begin(), children().end(), [](const Partition* p1, const Partition* p2) { return p1->deviceNode() < p2->deviceNode(); });
         for (const auto &child : children()) {
-            qint64 totalSector = child->length();
+            qint64 totalSectors = child->length();
             child->setFirstSector(lastEnd);
-            child->setLastSector(lastEnd + totalSector - 1);
+            child->setLastSector(lastEnd + totalSectors - 1);
 
-            lastEnd += totalSector;
+            lastEnd += totalSectors;
         }
     } else {
         const auto pChildren = p->children();
@@ -549,11 +554,6 @@ void PartitionTable::setType(const Device& d, TableType t)
     updateUnallocated(d);
 }
 
-static bool isPartitionLessThan(const Partition* p1, const Partition* p2)
-{
-    return p1->number() < p2->number();
-}
-
 QTextStream& operator<<(QTextStream& stream, const PartitionTable& ptable)
 {
     stream << "type: \"" << ptable.typeName() << "\"\n"
@@ -574,7 +574,7 @@ QTextStream& operator<<(QTextStream& stream, const PartitionTable& ptable)
         }
     }
 
-    qSort(partitions.begin(), partitions.end(), isPartitionLessThan);
+    qSort(partitions.begin(), partitions.end(), [](const Partition* p1, const Partition* p2) { return p1->number() < p2->number(); });
 
     foreach(const auto &p, partitions)
         stream << *p;
