@@ -25,6 +25,7 @@
 
 #include "core/partition.h"
 #include "core/device.h"
+#include "core/lvmdevice.h"
 
 #include "util/report.h"
 
@@ -54,26 +55,35 @@ bool SetPartGeometryJob::run(Report& parent)
 
     Report* report = jobStarted(parent);
 
-    CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
+    if(device().type() == Device::Disk_Device) {
+        CoreBackendDevice* backendDevice = CoreBackendManager::self()->backend()->openDevice(device().deviceNode());
 
-    if (backendDevice) {
-        CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
+        if (backendDevice) {
+            CoreBackendPartitionTable* backendPartitionTable = backendDevice->openPartitionTable();
 
-        if (backendPartitionTable) {
-            rval = backendPartitionTable->updateGeometry(*report, partition(), newStart(), newStart() + newLength() - 1);
+            if (backendPartitionTable) {
+                rval = backendPartitionTable->updateGeometry(*report, partition(), newStart(), newStart() + newLength() - 1);
 
-            if (rval) {
-                partition().setFirstSector(newStart());
-                partition().setLastSector(newStart() + newLength() - 1);
-                backendPartitionTable->commit();
+                if (rval) {
+                    partition().setFirstSector(newStart());
+                    partition().setLastSector(newStart() + newLength() - 1);
+                    backendPartitionTable->commit();
+                }
+
+                delete backendPartitionTable;
             }
 
-            delete backendPartitionTable;
-        }
 
-        delete backendDevice;
-    } else
-        report->line() << xi18nc("@info/plain", "Could not open device <filename>%1</filename> while trying to resize/move partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+            delete backendDevice;
+        } else
+            report->line() << xi18nc("@info:progress", "Could not open device <filename>%1</filename> while trying to resize/move partition <filename>%2</filename>.", device().deviceNode(), partition().deviceNode());
+    } else if (device().type() == Device::LVM_Device) {
+
+        partition().setFirstSector(newStart());
+        partition().setLastSector(newStart() + newLength() - 1);
+
+        rval = LvmDevice::resizeLV(*report, partition());
+    }
 
     jobFinished(*report, rval);
 
@@ -82,5 +92,5 @@ bool SetPartGeometryJob::run(Report& parent)
 
 QString SetPartGeometryJob::description() const
 {
-    return xi18nc("@info/plain", "Set geometry of partition <filename>%1</filename>: Start sector: %2, length: %3", partition().deviceNode(), newStart(), newLength());
+    return xi18nc("@info:progress", "Set geometry of partition <filename>%1</filename>: Start sector: %2, length: %3", partition().deviceNode(), newStart(), newLength());
 }
