@@ -53,7 +53,6 @@
 #include <KPluginFactory>
 
 #include <parted/parted.h>
-#include <unistd.h>
 
 K_PLUGIN_FACTORY_WITH_JSON(LibPartedBackendFactory, "pmlibpartedbackendplugin.json", registerPlugin<LibPartedBackend>();)
 
@@ -197,7 +196,8 @@ static void readSectorsUsed(PedDisk* pedDisk, const Device& d, Partition& p, con
     if (mountPoint != QString()) {
         const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
 
-        if (p.isMounted() && freeSpaceInfo.isValid() && mountPoint != QString())
+        // KDiskFreeSpaceInfo does not work with swap
+        if (p.isMounted() && freeSpaceInfo.isValid() && mountPoint != QString() && p.fileSystem().type() != FileSystem::LinuxSwap)
             p.fileSystem().setSectorsUsed(freeSpaceInfo.used() / d.logicalSize());
         else if (p.fileSystem().supportGetUsed() == FileSystem::cmdSupportFileSystem)
             p.fileSystem().setSectorsUsed(p.fileSystem().readUsedCapacity(p.deviceNode()) / d.logicalSize());
@@ -340,8 +340,9 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
         // libparted does not handle LUKS partitions
         if (fs->type() == FileSystem::Luks) {
             r |= PartitionRole::Luks;
-            FS::luks::initLUKS(fs);
-            QString mapperNode = static_cast<FS::luks*>(fs)->mapperName();
+            FS::luks* luksFs = static_cast<FS::luks*>(fs);
+            luksFs->initLUKS();
+            QString mapperNode = luksFs->mapperName();
             mountPoint = FileSystem::detectMountPoint(fs, mapperNode);
             mounted    = FileSystem::detectMountStatus(fs, mapperNode);
         } else {
@@ -414,7 +415,7 @@ QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
     // linux.git/tree/Documentation/devices.txt
     QString blockDeviceMajorNumbers = QStringLiteral(
         "3,22,33,34,56,57,88,89,90,91,128,129,130,131,132,133,134,135," // MFM, RLL and IDE hard disk/CD-ROM interface
-        "7," // loop devices
+        // "7," // loop devices TODO: add another bool option for loopDevices
         "8,65,66,67,68,69,70,71," // SCSI disk devices
         "80,81,82,83,84,85,86,87," // I2O hard disk
         "179," // MMC block devices
